(function() {
	//オーディオ生成用オブジェクト
	var player = null;

	/*
	 * Mediaファイルのパスを一時保存する
	 */
	function setMediaFilePath(hiddenObjectId, path) {
		document.getElementById(hiddenObjectId).value = path;
	}

	/*
	 * オーディオ録音
	 */
	captureAudio = function() {
		applican.capture.captureAudio(captureAudioSuccess, captureAudioError);
	}

	/*
	 * 録音成功時のCallback処理
	 */
	function captureAudioSuccess(mediaFiles) {
		var dump = "録音成功しました。\n";
		for (var i = 0, len = mediaFiles.length; i < len; i++) {
			dump += "path:";
			dump += mediaFiles[i].fullPath;
			setMediaFilePath("hidAudioFilePath", mediaFiles[i].fullPath);
		}
		document.getElementById("dumpAreaMedia").value = dump;
		alert(dump);
		//再生ボタンを表示
		document.getElementById("audioPlayBtn").style.display = "block";
		document.getElementById("audioStopBtn").style.display = "none";
	}

	/*
	 * 録音失敗時のCallback処理
	 * err.codeの説明
	 * 	・CaptureError.CAPTURE_INTERNAL_ERR = 0;
	 * 	　カメラまたはマイクが画像または音のキャプチャーに失敗した場合。
	 * 	・CaptureError.CAPTURE_APPLICATION_BUSY = 1;
	 * 	　カメラアプリまたはオーディオ録音アプリが現在他のキャプチャーリクエストを扱っている場合。
	 * 	・CaptureError.CAPTURE_INVALID_ARGUMENT = 2;
	 * 	　API の使用方法が不正であった場合 (例: limit パラメーターの値が1未満である) 。
	 * 	・CaptureError.CAPTURE_NO_MEDIA_FILES = 3;
	 * 	　ユーザーが何もキャプチャーせずにカメラアプリやオーディオ録音アプリを終了した場合。
	 * 	・CaptureError.CAPTURE_NOT_SUPPORTED = 20;
	 * 	　キャプチャー操作のリクエストがサポートされていない場合。
	 */
	function captureAudioError(err) {
		// ユーザーが何もキャプチャーせずにカメラアプリやオーディオ録音アプリを終了した場合
		if(err.code === 3) {
			return;
		}
		
		var dump = "録音失敗しました。\n";
		dump    += "code:"    + err.code    + "\n";
		dump    += "message:" + err.message + "\n";
		document.getElementById("dumpAreaMedia").value = dump;
		alert(dump);
	}

	/*
	 * オーディオ再生
	 */
	playAudio = function() {
		var src = document.getElementById("hidAudioFilePath").value;
		if(src === "") {
			return;
		}
		applican.media.createMediaPlayer(src, playAudioSuccess, playAudioError);
	}

	/*
	 * オーディオ再生成功時のCallback処理
	 */
	function playAudioSuccess(result) {
		player = result;
		player.play();
		switchPlayBtnDisplay("audioPlayBtn","audioStopBtn");
		var dump = "オーディオ再生成功しました。\n";
		document.getElementById("dumpAreaMedia").value = dump;
	}

	/*
	 * オーディオ再生失敗時のCallback処理
	 */
	function playAudioError(error) {
		var dump = "オーディオ再生成功失敗しました。\n";
		dump    += "code: "    + error.code    + "\n";
		dump    += "message: " + error.message + "\n";
		document.getElementById("dumpAreaMedia").value = dump;
	}

	/*
	 * オーディオ再生状態を取得する
	 */
	function playAudioStatus(status) {
		var dump = "playAudioStatus\n";
		dump    += "status: " + status;
		document.getElementById("dumpAreaMedia").value = dump;
	}

	/*
	 * オーディオ再生停止
	 */
	stopAudio = function() {
		player.stop();
		switchPlayBtnDisplay("audioPlayBtn", "audioStopBtn");
	}

	/*
	 * 再生ボタンの切り替え（生成←→停止）
	 */
	function switchPlayBtnDisplay(btnPlayId, btnStopId) {
		if(document.getElementById(btnStopId).style.display === "none") {
			document.getElementById(btnStopId).style.display = "block";
			document.getElementById(btnPlayId).style.display = "none";
		} else {
			document.getElementById(btnStopId).style.display = "none";
			document.getElementById(btnPlayId).style.display = "block";
		}
	}

	/********************* イベント登録 *********************/
	document.addEventListener("deviceready", function() {
		// 「オーディオ録音」ボタン押下処理
		document.getElementById("recordBtn").addEventListener("touchend", captureAudio, false);
		// 「オーディオ再生」ボタン押下処理
		document.getElementById("audioPlayBtn").addEventListener("touchend", playAudio, false);
		// 「オーディオ再生停止」ボタン押下処理
		document.getElementById("audioStopBtn").addEventListener("touchend", stopAudio, false);
		
		// プラットフォームがIOSの場合、録音ボタンを無効にする
		if (applican.device.platform !== "Android") {
			document.getElementById("recordBtn").disabled = true;
		}
	}, false);
})();
